<?php

namespace Netzmacher\QuickShop\TCA;

use TYPO3\CMS\Core\Utility\VersionNumberUtility;

/* * *************************************************************
 *  Copyright notice
 *
 *  (c) 2018-2019 - Dirk Wildt <http://wildt.at.die-netzmacher.de/>
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 * ************************************************************* */

/**
 * @author      Dirk Wildt <http://wildt.at.die-netzmacher.de>
 * @package     TYPO3
 * @subpackage  quick_shop
 * @version 8.14.0
 * @since 8.10.0
 */
class Columns
{

	/**
	 * @return string
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static public function Hidden()
	{
		return array(
				'exclude' => 1,
				'label' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'hidden' ][ 'label' ],
				'config' => array(
						'type' => 'check',
						'default' => '0'
				),
		);
	}

	/**
	 * @access public
	 * @param				array		$columns
	 * @param				boolean	$image_1stforlistonly
	 * @param				boolean $fal
	 * @return      array		$columns
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static public function ImageColumns( $columns, $image_1stforlistonly = false, $fal = 1 )
	{
		switch( $fal )
		{
			case(false):
				$imageColumns = SELF::_ImageColumnsCSV( $image_1stforlistonly );
			case(true):
			default:
				$imageColumns = SELF::_ImageColumnsFAL( $image_1stforlistonly );
		}

		$columns = ( array ) $columns + ( array ) $imageColumns;
		return $columns;
	}

	/**
	 * @access private
	 * @param				array		$columns
	 * @return      array		$columns
	 * @version     8.14.0
	 * @since       8.14.0
	 */
	static public function MediaColumns($columns)
	{
		$tcaColumnsMediaFAL = ( array ) $columns + array(
				// See: typo3/sysext/fluid_styled_content/Configuration/TCA/Overrides/tt_content.php
				'documents' => array(
						'label' => 'LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:tca_phrase.documents',
						'config' => \TYPO3\CMS\Core\Utility\ExtensionManagementUtility::getFileFieldTCAConfig( 'documents', array(
								'appearance' => array(
										'createNewRelationLinkTitle' => 'LLL:EXT:fluid_styled_content/Resources/Private/Language/Database.xlf:tt_content.asset_references.addFileReference'
								)
								, 'foreign_types' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'image' ][ 'config' ][ 'foreign_types' ]
										)
										, $GLOBALS[ 'TYPO3_CONF_VARS' ][ 'GFX' ][ 'imagefile_ext' ] . ',doc,docx,ods,odt,sxw,xls,xlsx'
						),
				),
				'documentslayout' => array(
						'exclude' => 1,
						'l10n_mode' => 'exclude',
						'label' => 'LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:tca_phrase.documentslayout',
						'config' => array(
								'type' => 'select',
								// #t1668, 171206, dwildt, 1+
								'renderType' => 'selectSingle',
								'size' => 1,
								'maxitems' => 1,
								'items' => array(
										array( 'LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:tca_phrase.documentslayout.0', 0 ),
										array( 'LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:tca_phrase.documentslayout.1', 1 ),
										array( 'LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:tca_phrase.documentslayout.2', 2 ),
								),
						),
				),
				'documentssize' => array(
						'exclude' => 1,
						//'l10n_mode' => 'exclude',
						'label' => 'LLL:EXT:quick_shop/Resources/Private/Language/6x/cms/locallang_ttc.xlf:filelink_size',
						'config' => array(
								'type' => 'check',
								'items' => array(
										'1' => array(
												'0' => 'LLL:EXT:lang/locallang_core.xml:labels.enabled',
										),
								),
								'default' => '1'
						),
				),
				'documents_from_path' => array(
						'exclude' => 1,
						//'l10n_mode' => 'exclude',
						'label' => 'LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:tca_phrase.documents_from_path',
						'config' => array(
								'type' => 'input',
								'size' => '50',
								'max' => '80',
								'eval' => 'trim',
						),
				),
		);

		return $tcaColumnsMediaFAL;
	}

	/**
	 * @param string $MMlocal table_local
	 * @param string $MMforeign table_foreign
	 * @param string $OrderBy Orderby field
	 * @param string $MMopposite Opposite field in case of an opposite relation.
	 * @return array
	 * @access public
	 * @version 8.10.3
	 * @since 8.10.3
	 */
	static public function SelectMultipleSideBySide( $MMlocal, $MMforeign, $OrderBy = NULL, $MMopposite = NULL )
	{
		$where = SELF::_selectWhere( $MMlocal, $MMforeign, $OrderBy, $MMopposite );
		return array(
				'exclude' => 1,
				//'l10n_mode' => 'mergeIfNotBlank',
				'label' => 'LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:' . $MMforeign,
				'config' => \Netzmacher\QuickShop\TCA\Columns\Config::SelectMultipleSideBySide(
								$MMlocal
								, $MMforeign
								, $MMopposite
								, $where
								, 9999
				),
		);
	}

	/**
	 * @return array
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static public function Type()
	{
		return array(
				'exclude' => 1,
				'l10n_mode' => 'exclude',
				'label' => 'LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:type',
				'config' => array(
						'type' => 'select',
						'renderType' => 'selectSingle',
						'items' => array(
								'record' => array(
										'0' => 'LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:type_record',
										'1' => 'record',
										'2' => \Netzmacher\QuickShop\TCA\Columns\Type\Items::IconRecord(),
								),
								'page' => array(
										'0' => 'LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:type_page',
										'1' => 'page',
										'2' => \Netzmacher\QuickShop\TCA\Columns\Type\Items::IconPage(),
								),
								'url' => array(
										'0' => 'LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:type_url',
										'1' => 'url',
										'2' => \Netzmacher\QuickShop\TCA\Columns\Type\Items::IconUrl(),
								),
								'notype' => array(
										'0' => 'LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:type_notype',
										'1' => 'notype',
										'2' => \Netzmacher\QuickShop\TCA\Columns\Type\Items::IconNotype(),
								),
						),
						'default' => 'record',
				),
		);
	}

	/**
	 * UidParent() : Renders a TCA selecttree
	 *
	 * @param string $label From a locallang.xlf
	 * @param string $foreign foreign_table
	 * @param string $where SQL-where-statement for table_foreign
	 * @param integer $size Size of the visible parte of the tree in lines
	 * @param boolean $expandAll expand the tree by default 
	 * @param string $parentField foreign_table
	 * 
	 * @return void
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static function UidParent( $label, $foreign_table, $where = NULL, $size = 20, $expandAll = false, $parentField = 'uid_parent' )
	{
		$return = array(
				'exclude' => 1,
				'label' => $label,
				'config' => array(
						'type' => 'select',
						'renderMode' => 'tree', // TYPO3 6.x
						'renderType' => 'selectTree', // TYPO3 7.6
						'foreign_table' => $foreign_table,
						'size' => $size,
						'treeConfig' => array(
								'parentField' => $parentField,
								'appearance' => array(
										'expandAll' => $expandAll,
										'showHeader' => true,
								),
						),
				),
		);

		if( $where )
		{
			$return[ 'config' ][ 'foreign_table_where' ] = $where;
		}

		return $return;
	}

	/**
	 * @return string
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static public function URL()
	{
		return array(
				'exclude' => 0,
//          'l10n_mode' => 'exclude',
				'label' => 'LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:label.page',
				'config' => \Netzmacher\QuickShop\TCA\Columns\Wizards::Url(),
		);
	}

	/**
	 * @access private
	 * @param				string	$case: small || medieum || big
	 * @param				boolean $fal
	 * @return      string
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static private function _ImageColumnsCSV( $image_1stforlistonly = false )
	{
		$_pathLL = SELF::_pathLL();
		$_pathIcon = SELF::_pathIcon();

		$image = array(
				'image' => array(
						'exclude' => 1,
						'label' => 'LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:tca_phrase.image',
						'config' => \Netzmacher\QuickShop\TCA\Columns\Config::Image(),
				),
				'imagecaption' => array(
						'exclude' => 1,
						'l10n_mode' => 'prefixLangTitle',
						'label' => 'LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:tca_phrase.imagecaption',
						'config' => array(
								'type' => 'text',
								'cols' => '30',
								'rows' => '5',
						),
				),
				'imagecaption_position' => array(
						'exclude' => 1,
//      'l10n_mode' => 'exclude',
						'label' => 'LLL:EXT:' . $_pathLL . ':imagecaption_position',
						'config' => array(
								'type' => 'select',
								'items' => array(
										array( '', '' ),
										array( 'LLL:EXT:' . $_pathLL . ':imagecaption_position.I.1', 'center' ),
										array( 'LLL:EXT:' . $_pathLL . ':imagecaption_position.I.2', 'right' ),
										array( 'LLL:EXT:' . $_pathLL . ':imagecaption_position.I.3', 'left' ),
								),
								'default' => ''
						),
				),
				'imageseo' => array(
						'exclude' => 1,
						'l10n_mode' => 'prefixLangTitle',
						'label' => 'LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:tca_phrase.imageseo',
						'config' => array(
								'type' => 'text',
								'cols' => '30',
								'rows' => '5',
						),
				),
				'imagewidth' => array(
						'exclude' => 1,
//      'l10n_mode' => 'exclude',
						'label' => 'LLL:EXT:' . $_pathLL . ':imagewidth',
						'config' => array(
								'type' => 'input',
								'size' => '10',
								'max' => '10',
								'eval' => 'trim',
								'checkbox' => '0',
								'default' => ''
						),
				),
				'imageheight' => array(
						'exclude' => 1,
//      'l10n_mode' => 'exclude',
						'label' => 'LLL:EXT:' . $_pathLL . ':imageheight',
						'config' => array(
								'type' => 'input',
								'size' => '10',
								'max' => '10',
								'eval' => 'trim',
								'checkbox' => '0',
								'default' => ''
						),
				),
				'imageorient' => array(
						'exclude' => 1,
//      'l10n_mode' => 'exclude',
						'label' => 'LLL:EXT:' . $_pathLL . ':imageorient',
						'config' => array(
								'type' => 'select',
								'items' => array(
										array( 'LLL:EXT:' . $_pathLL . ':imageorient.I.0', 0, $_pathIcon . 'above_center.gif' ),
										array( 'LLL:EXT:' . $_pathLL . ':imageorient.I.1', 1, $_pathIcon . 'above_right.gif' ),
										array( 'LLL:EXT:' . $_pathLL . ':imageorient.I.2', 2, $_pathIcon . 'above_left.gif' ),
										array( 'LLL:EXT:' . $_pathLL . ':imageorient.I.3', 8, $_pathIcon . 'below_center.gif' ),
										array( 'LLL:EXT:' . $_pathLL . ':imageorient.I.4', 9, $_pathIcon . 'below_right.gif' ),
										array( 'LLL:EXT:' . $_pathLL . ':imageorient.I.5', 10, $_pathIcon . 'below_left.gif' ),
										array( 'LLL:EXT:' . $_pathLL . ':imageorient.I.6', 17, $_pathIcon . 'intext_right.gif' ),
										array( 'LLL:EXT:' . $_pathLL . ':imageorient.I.7', 18, $_pathIcon . 'intext_left.gif' ),
										array( 'LLL:EXT:' . $_pathLL . ':imageorient.I.8', '--div--' ),
										array( 'LLL:EXT:' . $_pathLL . ':imageorient.I.9', 25, $_pathIcon . 'intext_right_nowrap.gif' ),
										array( 'LLL:EXT:' . $_pathLL . ':imageorient.I.10', 26, $_pathIcon . 'intext_left_nowrap.gif' ),
								),
								'selicon_cols' => 6,
								'default' => '0',
								'iconsInOptionTags' => 1,
						),
				),
				'imageborder' => array(
						'exclude' => 1,
//      'l10n_mode' => 'exclude',
						'label' => 'LLL:EXT:' . $_pathLL . ':imageborder',
						'config' => array(
								'type' => 'check'
						),
				),
				'image_noRows' => array(
						'exclude' => 1,
//      'l10n_mode' => 'exclude',
						'label' => 'LLL:EXT:' . $_pathLL . ':image_noRows',
						'config' => array(
								'type' => 'check'
						),
				),
				'image_link' => array(
						'exclude' => 1,
//      'l10n_mode' => 'exclude',
						'label' => 'LLL:EXT:' . $_pathLL . ':image_link',
						//'config' => $arr_wizard_url,
						'config' => \Netzmacher\QuickShop\TCA\Columns\Wizards::Url(),
				),
				'image_zoom' => array(
						'exclude' => 1,
//      'l10n_mode' => 'exclude',
						'label' => 'LLL:EXT:' . $_pathLL . ':image_zoom',
						'config' => array(
								'type' => 'check'
						),
				),
				'image_effects' => array(
						'exclude' => 1,
//      'l10n_mode' => 'exclude',
						'label' => 'LLL:EXT:' . $_pathLL . ':image_effects',
						'config' => array(
								'type' => 'select',
								'items' => array(
										array( 'LLL:EXT:' . $_pathLL . ':image_effects.I.0', 0 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_effects.I.1', 1 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_effects.I.2', 2 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_effects.I.3', 3 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_effects.I.4', 10 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_effects.I.5', 11 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_effects.I.6', 20 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_effects.I.7', 23 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_effects.I.8', 25 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_effects.I.9', 26 ),
								),
						),
				),
				'image_frames' => array(
						'exclude' => 1,
//      'l10n_mode' => 'exclude',
						'label' => 'LLL:EXT:' . $_pathLL . ':image_frames',
						'config' => array(
								'type' => 'select',
								'items' => array(
										array( 'LLL:EXT:' . $_pathLL . ':image_frames.I.0', 0 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_frames.I.1', 1 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_frames.I.2', 2 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_frames.I.3', 3 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_frames.I.4', 4 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_frames.I.5', 5 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_frames.I.6', 6 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_frames.I.7', 7 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_frames.I.8', 8 ),
								),
						),
				),
				'image_compression' => array(
						'exclude' => 1,
//      'l10n_mode' => 'exclude',
						'label' => 'LLL:EXT:' . $_pathLL . ':image_compression',
						'config' => array(
								'type' => 'select',
								'items' => array(
										array( 'LLL:EXT:lang/locallang_general.php:LGL.default_value', 0 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_compression.I.1', 1 ),
										array( 'GIF/256', 10 ),
										array( 'GIF/128', 11 ),
										array( 'GIF/64', 12 ),
										array( 'GIF/32', 13 ),
										array( 'GIF/16', 14 ),
										array( 'GIF/8', 15 ),
										array( 'PNG', 39 ),
										array( 'PNG/256', 30 ),
										array( 'PNG/128', 31 ),
										array( 'PNG/64', 32 ),
										array( 'PNG/32', 33 ),
										array( 'PNG/16', 34 ),
										array( 'PNG/8', 35 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_compression.I.15', 21 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_compression.I.16', 22 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_compression.I.17', 24 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_compression.I.18', 26 ),
										array( 'LLL:EXT:' . $_pathLL . ':image_compression.I.19', 28 ),
								),
						),
				),
				'imagecols' => array(
						'exclude' => 1,
//      'l10n_mode' => 'exclude',
						'label' => 'LLL:EXT:' . $_pathLL . ':imagecols',
						'config' => array(
								'type' => 'select',
								'items' => array(
										array( '1', 1 ),
										array( '2', 2 ),
										array( '3', 3 ),
										array( '4', 4 ),
										array( '5', 5 ),
										array( '6', 6 ),
										array( '7', 7 ),
										array( '8', 8 ),
								),
								'default' => 1
						),
				),
		);

		if( $image_1stforlistonly )
		{
			$image = $image + array(
					'image_1stforlistonly' => array(
							'exclude' => 1,
							'l10n_mode' => 'exclude',
							'label' => 'LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:tca_phrase.image_1stforlistonly',
							'config' => array(
									'type' => 'check'
							),
					),
			);
		}

		return $image;
	}

	/**
	 * @access private
	 * @param				string	$case: small || medieum || big
	 * @param				boolean $fal
	 * @return      string
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static private function _ImageColumnsFAL( $image_1stforlistonly = false )
	{
		$TYPO3_version = VersionNumberUtility::convertVersionNumberToInteger( TYPO3_version );

		switch( TRUE )
		{
			case ( $TYPO3_version < 8007000 ):
				return SELF::_ImageColumnsFALCss( $image_1stforlistonly );
			case ( $TYPO3_version >= 8007000 ):
			default:
				return SELF::_ImageColumnsFALFluid( $image_1stforlistonly );
		}
	}

	/**
	 * @param				string	$case: small || medieum || big
	 * @param				boolean $fal
	 * @return      string
	 * @access private
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static private function _ImageColumnsFALCss( $image_1stforlistonly = false )
	{
		$image = array(
				'image' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'image' ],
				'imagewidth' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'imagewidth' ],
				'imageheight' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'imageheight' ],
				'imageorient' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'imageorient' ],
				'imageborder' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'imageborder' ],
				'image_zoom' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'image_zoom' ],
				'imagecols' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'imagecols' ],
				// #i0253, 180913, dwildt, 3-
//				'image_compression' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'image_compression' ],
//				'image_effects' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'image_effects' ],
//				'image_noRows' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'image_noRows' ],
				'layout' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'layout' ],
						// #i0253, 180913, dwildt, 3-
//				'section_frame' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'section_frame' ],
//				'spaceAfter' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'spaceAfter' ],
//				'spaceBefore' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'spaceBefore' ],
		);

		unset( $image[ 'imageheight' ][ 'config' ][ 'eval' ] );
		unset( $image[ 'imagewidth' ][ 'config' ][ 'eval' ] );
		unset( $image[ 'imageheight' ][ 'config' ][ 'range' ] );
		unset( $image[ 'imagewidth' ][ 'config' ][ 'range' ] );
		$image[ 'imageheight' ][ 'config' ][ 'max' ] = 5;
		$image[ 'imageheight' ][ 'config' ][ 'size' ] = 5;
		$image[ 'imagewidth' ][ 'config' ][ 'max' ] = 5;
		$image[ 'imagewidth' ][ 'config' ][ 'size' ] = 5;

		if( $image_1stforlistonly )
		{
			$image = $image + array(
					'image_1stforlistonly' => array(
							'exclude' => 1,
							'l10n_mode' => 'exclude',
							'label' => 'LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:tca_phrase.image_1stforlistonly',
							'config' => array(
									'type' => 'check'
							),
					),
			);
		}

		return $image;
	}

	/**
	 * @param				string	$case: small || medieum || big
	 * @param				boolean $fal
	 * @return      string
	 * @access private
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static private function _ImageColumnsFALFluid( $image_1stforlistonly = false )
	{
		$image = array(
				'frame_class' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'frame_class' ],
				'image' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'image' ],
				'imageborder' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'imageborder' ],
				'imagecols' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'imagecols' ],
				'imageheight' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'imageheight' ],
				'imageorient' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'imageorient' ],
				'imagewidth' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'imagewidth' ],
				'image_zoom' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'image_zoom' ],
				'layout' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'layout' ],
				'space_after_class' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'space_after_class' ],
				'space_before_class' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'space_before_class' ],
		);

		unset( $image[ 'imageheight' ][ 'config' ][ 'eval' ] );
		unset( $image[ 'imagewidth' ][ 'config' ][ 'eval' ] );
		unset( $image[ 'imageheight' ][ 'config' ][ 'range' ] );
		unset( $image[ 'imagewidth' ][ 'config' ][ 'range' ] );
		$image[ 'imageheight' ][ 'config' ][ 'max' ] = 5;
		$image[ 'imageheight' ][ 'config' ][ 'size' ] = 5;
		$image[ 'imagewidth' ][ 'config' ][ 'max' ] = 5;
		$image[ 'imagewidth' ][ 'config' ][ 'size' ] = 5;

		if( $image_1stforlistonly )
		{
			$image = $image + array(
					'image_1stforlistonly' => array(
							'exclude' => 1,
							'l10n_mode' => 'exclude',
							'label' => 'LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:tca_phrase.image_1stforlistonly',
							'config' => array(
									'type' => 'check'
							),
					),
			);
		}

		return $image;
	}

	/**
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _pathLL()
	{
		$TYPO3_version = VersionNumberUtility::convertVersionNumberToInteger( TYPO3_version );

		switch( TRUE )
		{
			case ( $TYPO3_version < 7006000 ):
				return 'quick_shop/Resources/Private/Language/6x/cms/locallang_ttc.xlf';
			case ( $TYPO3_version >= 7006000 ):
			default:
				return 'frontend/Resources/Private/Language/locallang_ttc.xlf';
		}
	}

	/**
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _pathIcon()
	{
		$TYPO3_version = VersionNumberUtility::convertVersionNumberToInteger( TYPO3_version );

		switch( TRUE )
		{
			case ( $TYPO3_version < 7006000 ):
				return 'selicons/';
			case ( $TYPO3_version >= 7006000 ):
			default:
				return 'EXT:frontend/Resources/Public/Icons/ImageOrientation/';
		}
	}

	/**
	 * @param		string $table
	 * @param		string $orderby
	 * @return string
	 * @access private
	 * @version 8.10.3
	 * @since 8.10.3
	 */
	static private function _selectOrderBy( $table, $orderby )
	{
		switch( true )
		{
			case( empty( $orderby ) ):
				return $table . '.title';
			case(!empty( $orderby ) ):
			default:
				return $orderby;
		}
	}

	/**
	 * @param string $MMlocal table_local
	 * @param string $MMforeign table_foreign
	 * @param string $OrderBy Orderby field
	 * @param string $MMopposite Opposite field in case of an opposite relation.
	 * @return array
	 * @access public
	 * @version 8.10.3
	 * @since 8.10.3
	 */
	static private function _selectWhere( $MMlocal, $MMforeign, $OrderBy = NULL, $MMopposite = NULL )
	{
		switch( true )
		{
			case( empty( $MMopposite ) ):
				return ''
								. 'AND ' . $MMforeign . '.pid=###CURRENT_PID### '
								. 'AND ' . $MMforeign . '.deleted = 0 '
								. 'AND ' . $MMforeign . '.hidden = 0 '
								. 'ORDER BY ' . SELF::_selectOrderBy( $MMforeign, $OrderBy )
				;
			case(!empty( $MMopposite ) ):
			default:
				return ''
								. 'AND ' . $MMlocal . '.pid=###CURRENT_PID### '
								. 'AND ' . $MMlocal . '.deleted = 0 '
								. 'AND ' . $MMlocal . '.hidden = 0 '
								. 'ORDER BY ' . SELF::_selectOrderBy( $MMlocal, $OrderBy )
				;
		}
	}

}
