<?php

namespace Netzmacher\QuickShop\TCA\Columns;

use TYPO3\CMS\Core\Utility\VersionNumberUtility;

/* * *************************************************************
 *  Copyright notice
 *
 *  (c) 2018-2019 - Dirk Wildt <http://wildt.at.die-netzmacher.de/>
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 * ************************************************************* */

/**
 * @version 8.10.3
 * @since 8.10.3
 */
class Config
{

	/**
	 * Image()
	 * 
	 * @return array
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static public function Image()
	{
		return array(
				'type' => 'group',
				'internal_type' => 'file',
				'allowed' => $GLOBALS[ 'TYPO3_CONF_VARS' ][ 'GFX' ][ 'imagefile_ext' ],
				'max_size' => $GLOBALS[ 'TYPO3_CONF_VARS' ][ 'BE' ][ 'maxFileSize' ],
				'uploadfolder' => 'uploads/tx_quickshop',
				'show_thumbs' => 1,
				'size' => 3,
				'minitems' => 0,
				'maxitems' => 20,
		);
	}

	/**
	 * RTE()
	 * 
	 * @return array
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static public function RTE()
	{
		$TYPO3_version = VersionNumberUtility::convertVersionNumberToInteger( TYPO3_version );

		switch( TRUE )
		{
			case ( $TYPO3_version < 8007000 ):
				return SELF::_RTE76();
			case ( $TYPO3_version >= 8007000 ):
			default:
				return SELF::_RTE87();
		}
	}

	/**
	 * @param string $MMlocal table_local
	 * @param string $MMforeign table_foreign
	 * @param string $MMopposite Opposite field in case of an opposite relation.
	 * @param string $where SQL-where-statement for table_foreign
	 * @param integer $maxItems
	 * @param integer $size Size of the visible parte of the tree in lines
	 * @param string $MM MM-table, the table for relations
	 * 
	 * @return array
	 * @access public
	 * @version 8.10.3
	 * @since 8.10.3
	 */
	static function SelectMultipleSideBySide( $MMlocal, $MMforeign, $MMopposite = NULL, $where = NULL, $maxItems = 9999, $size = 20, $MM = 'tx_quickshop_mm' )
	{
		$foreign = $MMforeign;
		if( $MMopposite )
		{
			$foreign = $MMlocal;
		}
		$return = array(
				'enableMultiSelectFilterTextfield' => true,
				'foreign_table' => $foreign,
				'maxitems' => $maxItems,
				'MM' => $MM,
				"MM_match_fields" => array(
						'table_local' => $MMlocal,
						'table_foreign' => $MMforeign,
				),
				"MM_insert_fields" => array(
						'table_local' => $MMlocal,
						'table_foreign' => $MMforeign,
				),
				'renderMode' => 'singlebox', // TYPO3 6.x
				'renderType' => 'selectMultipleSideBySide', // TYPO3 7.x
//				'size' => $size,
				'type' => 'select',
		);

		if( $MMopposite )
		{
			$return[ 'MM_opposite_field' ] = $MMopposite;
		}
		if( $where )
		{
			$return[ 'foreign_table_where' ] = $where;
		}

		return $return;
	}

	/**
	 * SelectTree() : Renders a TCA selecttree
	 *
	 * @param string $MMlocal table_local
	 * @param string $MMforeign table_foreign
	 * @param string $where SQL-where-statement for table_foreign
	 * @param integer $size Size of the visible parte of the tree in lines
	 * @param boolean $expandAll expand the tree by default 
	 * @param string $MM MM-table, the table for relations
	 * @param string $foreign foreign_table
	 * @param string $MMopposite Opposite field in case of an opposite relation.
	 * @param string $parentField foreign_table
	 * 
	 * @return array
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static function SelectTree( $MMlocal, $MMforeign, $where = NULL, $size = 20, $expandAll = false, $MM = 'tx_quickshop_mm', $foreign = NULL, $MMopposite = NULL, $parentField = 'uid_parent' )
	{
		if( !$foreign )
		{
			$foreign = $MMforeign;
		}
		$return = array(
				'behaviour' => array(
						'allowLanguageSynchronization' => true,
				),
				'maxitems' => 9999,
				'MM' => $MM,
				"MM_match_fields" => array(
						'table_local' => $MMlocal,
						'table_foreign' => $MMforeign,
				),
				"MM_insert_fields" => array(
						'table_local' => $MMlocal,
						'table_foreign' => $MMforeign,
				),
				'renderMode' => 'tree', // TYPO3 6.x
				'renderType' => 'selectTree', // TYPO3 7.x
				'size' => $size,
				'treeConfig' => array(
						'parentField' => $parentField,
						'appearance' => array(
								'expandAll' => $expandAll,
								'showHeader' => true,
						),
				),
				'type' => 'select',
		);

		if( $foreign )
		{
			$return[ 'foreign_table' ] = $foreign;
		}
		if( $MMopposite )
		{
			$return[ 'MM_opposite_field' ] = $MMopposite;
		}
		if( $where )
		{
			$return[ 'foreign_table_where' ] = $where;
		}

		return $return;
	}

	/**
	 * _RTE76()
	 * 
	 * @return array
	 * @access private
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static private function _RTE76()
	{
		return array(
				'type' => 'text',
				'cols' => '30',
				'rows' => '5',
				'eval' => 'trim',
				'wizards' => array(
						'_PADDING' => 2,
						'RTE' => array(
								'notNewRecords' => 1,
								'RTEonly' => 1,
								'type' => 'script',
								'title' => 'Full screen Rich Text Editing|Formatteret redigering i hele vinduet',
								'icon' => 'wizard_rte2.gif',
								'module' => array(
										'name' => 'wizard_rte',
								),
						),
				),
		);
	}

	/**
	 * _RTE87()
	 * 
	 * @return array
	 * @access private
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static private function _RTE87()
	{
		return array(
				'type' => 'text',
				'cols' => '30',
				'rows' => '5',
				'eval' => 'trim',
				'fieldControl' => array(
						'fullScreenRichtext' => array(
								'disabled' => '',
						),
				),
				'enableRichtext' => true,
		);
	}

}
